Installation
============

:code:`stark` can be installed from source,

.. code-block:: bash

    git clone https://github.com/Jayshil/stark

to download the source code and then,    

.. code-block:: bash

    python setup.py install

to install :code:`stark` after switching the directory.